@@ -9,7 +9,7 @@ class UI:
     Добавляет возможность vk ui _инкапсуляторам_
     (клаиватуры, карусели...)
     возможнсть генерации по словарю (напрямую в JSON)
-    и саму конфертацию через __repr__
+    и саму конфертацию через `__repr__`
     """
 
     def __repr__(self) -> str:
